@@ -1,16 +1,18 @@
 from __future__ import absolute_import, division, print_function
 
 import stripe
-from stripe import api_requestor, util
+from stripe import api_requestor
+from stripe import util
 from stripe.api_resources.abstract import ListableAPIResource
 
 
 class File(ListableAPIResource):
+    OBJECT_NAME = "file"
+
     # This resource can have two different object names. In latter API
     # versions, only `file` is used, but since stripe-python may be used with
     # any API version, we need to support deserializing the older
     # `file_upload` object into the same class.
-    OBJECT_NAME = "file"
     OBJECT_NAME_ALT = "file_upload"
 
     @classmethod
@@ -19,12 +21,19 @@ class File(ListableAPIResource):
 
     @classmethod
     def create(
-        cls, api_key=None, api_version=None, stripe_account=None, **params
+        # 'api_version' is deprecated, please use 'stripe_version'
+        cls,
+        api_key=None,
+        api_version=None,
+        stripe_version=None,
+        stripe_account=None,
+        **params
     ):
+        version = api_version or stripe_version
         requestor = api_requestor.APIRequestor(
             api_key,
             api_base=stripe.upload_api_base,
-            api_version=api_version,
+            api_version=version,
             account=stripe_account,
         )
         url = cls.class_url()
@@ -33,7 +42,7 @@ class File(ListableAPIResource):
             "post", url, params=params, headers=supplied_headers
         )
         return util.convert_to_stripe_object(
-            response, api_key, api_version, stripe_account
+            response, api_key, version, stripe_account
         )
 
 
