@@ -2,12 +2,18 @@ from __future__ import absolute_import, division, print_function
 
 from stripe import util
 from stripe.api_resources.abstract import CreateableAPIResource
-from stripe.api_resources.abstract import UpdateableAPIResource
 from stripe.api_resources.abstract import ListableAPIResource
+from stripe.api_resources.abstract import UpdateableAPIResource
+from stripe.api_resources.abstract import custom_method
 
 
+@custom_method("cancel", http_verb="post")
+@custom_method("capture", http_verb="post")
+@custom_method("confirm", http_verb="post")
 class PaymentIntent(
-    CreateableAPIResource, UpdateableAPIResource, ListableAPIResource
+    CreateableAPIResource,
+    ListableAPIResource,
+    UpdateableAPIResource,
 ):
     OBJECT_NAME = "payment_intent"
 
