@@ -5,14 +5,14 @@ from stripe.api_resources.abstract import CreateableAPIResource
 from stripe.api_resources.abstract import ListableAPIResource
 from stripe.api_resources.abstract import UpdateableAPIResource
 from stripe.api_resources.abstract import custom_method
-from stripe.api_resources.abstract import nested_resource_class_methods
 
 
 @custom_method("cancel", http_verb="post")
 @custom_method("release", http_verb="post")
-@nested_resource_class_methods("revision", operations=["retrieve", "list"])
 class SubscriptionSchedule(
-    CreateableAPIResource, ListableAPIResource, UpdateableAPIResource
+    CreateableAPIResource,
+    ListableAPIResource,
+    UpdateableAPIResource,
 ):
     OBJECT_NAME = "subscription_schedule"
 
@@ -27,6 +27,3 @@ class SubscriptionSchedule(
         headers = util.populate_headers(idempotency_key)
         self.refresh_from(self.request("post", url, params, headers))
         return self
-
-    def revisions(self, **params):
-        return self.request("get", self.instance_url() + "/revisions", params)
