@@ -4,4 +4,4 @@ from stripe.api_resources.abstract import CreateableAPIResource
 
 
 class Token(CreateableAPIResource):
-    OBJECT_NAME = 'token'
+    OBJECT_NAME = "token"
